@@ -10,6 +10,7 @@ tg_auth <- function(
 ) {
 
   Sys.setenv('TG_API_TOKEN' = token)
+  options(tg.api_token = token)
   cli_alert_success('API token was set success!')
 
 }
@@ -19,5 +20,12 @@ tg_auth <- function(
 #' @return Api token
 #' @export
 tg_get_token <- function() {
-  Sys.getenv('TG_API_TOKEN')
+  if (!is.null(getOption('tg.api_token'))) {
+    return(getOption('tg.api_token'))
+  }
+  if (identical(Sys.getenv('TG_API_TOKEN'), "")) {
+    cli_abort("API token does't set. Please use tg_auth() for authorization.")
+  } else {
+    return(Sys.getenv('TG_API_TOKEN'))
+  }
 }
